==> dynamodb-keyspace-0.0.6.tgz: package/dist-es/command/Get.js <==
import { GetCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { lowerCaseKeys, upperCaseKeys } from '../util/keyCapitalize';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
const GET_COMMAND_INPUT_DATA_TYPE = 'GetCommandInput';
const GET_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', GET_COMMAND_INPUT_DATA_TYPE];
const GET_COMMAND_OUTPUT_DATA_TYPE = 'GetCommandOutput';
const GET_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'ReadCommandOutput', GET_COMMAND_OUTPUT_DATA_TYPE];
export class DkGetCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: GET_COMMAND_INPUT_DATA_TYPE, hooks: GET_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: GET_COMMAND_OUTPUT_DATA_TYPE, hooks: GET_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, ['returnConsumedCapacity']);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const upperCaseInput = upperCaseKeys(postMiddlewareInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = lowerCaseKeys(output);
            const item = output.Item;
            if (!item)
                throw new Error('Item Not Found');
            const formattedOutput = {
                ...lowerCaseOutput,
                item
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity)
                await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.consumedCapacity }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new GetCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}

==> dynamodb-keyspace-0.0.7.tgz: package/dist-es/command/Get.js <==
import { GetCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { uncapitalizeKeys, capitalizeKeys } from 'object-key-casing';
import { applyDefaults } from '../util/defaults';
import { executeMiddlewares, executeMiddleware } from '../Middleware';
const GET_COMMAND_INPUT_DATA_TYPE = 'GetCommandInput';
const GET_COMMAND_INPUT_HOOK = ['CommandInput', 'ReadCommandInput', GET_COMMAND_INPUT_DATA_TYPE];
const GET_COMMAND_OUTPUT_DATA_TYPE = 'GetCommandOutput';
const GET_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'ReadCommandOutput', GET_COMMAND_OUTPUT_DATA_TYPE];
export class DkGetCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: GET_COMMAND_INPUT_DATA_TYPE, hooks: GET_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: GET_COMMAND_OUTPUT_DATA_TYPE, hooks: GET_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, ['returnConsumedCapacity']);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const upperCaseInput = capitalizeKeys(postMiddlewareInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = uncapitalizeKeys(output);
            const item = output.Item;
            if (!item)
                throw new Error('Item Not Found');
            const formattedOutput = {
                ...lowerCaseOutput,
                item
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity)
                await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.consumedCapacity }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new GetCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
